@@ -551,8 +551,6 @@ QMailMessageServiceEditor *VkConfigurator::createEditor(
 }
 #endif
 
-Q_EXPORT_PLUGIN2(vk,VkServicePlugin)
-
 VkServicePlugin::VkServicePlugin()
     : QMailMessageServicePlugin()
 {
@@ -587,3 +585,31 @@ QMailMessageServiceConfigurator *VkServicePlugin::createServiceConfigurator()
 }
 
 #include "vkservice.moc"
+
+#  define MY_PLUGIN_VERIFICATION_DATA \
+	            static const char *my_plugin_verification_data = \
+      "pattern=""QT_PLUGIN_VERIFICATION_DATA""\n" \
+      "version="QT_VERSION_STR"\n" \
+      "debug="QPLUGIN_DEBUG_STR"\n" \
+      "buildkey=""armv6 linux g++-4 full-config";
+
+#  define MY_EXPORT_PLUGIN2(PLUGIN, PLUGINCLASS)      \
+	                    MY_PLUGIN_VERIFICATION_DATA \
+            Q_EXTERN_C Q_DECL_EXPORT \
+            const char * Q_STANDARD_CALL qt_plugin_query_verification_data() \
+            { return my_plugin_verification_data; } \
+            Q_EXTERN_C Q_DECL_EXPORT QT_PREPEND_NAMESPACE(QObject) * Q_STANDARD_CALL qt_plugin_instance() \
+            Q_PLUGIN_INSTANCE(PLUGINCLASS)
+
+/* Adding plugin debug string */
+#ifdef QPLUGIN_DEBUG_STR
+#    undef QPLUGIN_DEBUG_STR
+#endif
+#define QPLUGIN_DEBUG_STR "true"
+
+#ifdef Q_WS_MAEMO5
+MY_EXPORT_PLUGIN2(vk,VkServicePlugin)
+#else
+Q_EXPORT_PLUGIN2(vk,VkServicePlugin)
+#endif
+	
