@@ -2,9 +2,6 @@
 #include "testwindow.h"
 
 int main(int argc, char *argv[]) {
-    Q_UNUSED(argc);
-    Q_UNUSED(argv);
-
     QApplication app(argc, argv);
     TestWindow w;
     w.show();
